@@ -1,5 +1,6 @@
 from pydantic import BaseModel, Field
-from alumnium.drivers import SeleniumDriver
+
+from alumnium.drivers import BaseDriver
 
 
 class HoverTool(BaseModel):
@@ -7,5 +8,5 @@ class HoverTool(BaseModel):
 
     id: int = Field(description="Element identifier (ID)")
 
-    def invoke(self, driver: SeleniumDriver):
+    def invoke(self, driver: BaseDriver):
         driver.hover(self.id)
