@@ -1,5 +1,6 @@
 from pydantic import BaseModel, Field
-from alumnium.drivers import SeleniumDriver
+
+from alumnium.drivers import BaseDriver
 
 
 class TypeTool(BaseModel):
@@ -7,7 +8,6 @@ class TypeTool(BaseModel):
 
     id: int = Field(description="Element identifier (ID)")
     text: str = Field(description="Text to type into an element")
-    submit: bool = Field(description="Submit after typing text by pressing `Enter` key")
 
-    def invoke(self, driver: SeleniumDriver):
-        driver.type(self.id, self.text, self.submit)
+    def invoke(self, driver: BaseDriver):
+        driver.type(self.id, self.text)
